@@ -6,16 +6,16 @@ import (
 
 type logger struct{}
 
-func (l *logger) Info(msg string, keysAndValues ...interface{}) {
-	args := []interface{}{
+func (l *logger) Info(msg string, keysAndValues ...any) {
+	args := []any{
 		"Scheduler: " + msg,
 	}
 	args = append(args, keysAndValues...)
 	log.Debug(args...)
 }
 
-func (l *logger) Error(err error, msg string, keysAndValues ...interface{}) {
-	args := []interface{}{
+func (l *logger) Error(err error, msg string, keysAndValues ...any) {
+	args := []any{
 		"Scheduler: " + msg,
 	}
 	args = append(args, keysAndValues...)
