@@ -1,11 +1,13 @@
 package goose
 
 import (
+	"cmp"
 	"context"
 	"database/sql"
 	"errors"
 	"fmt"
 	"io/fs"
+	"log/slog"
 	"math"
 	"strconv"
 	"strings"
@@ -63,7 +65,6 @@ func NewProvider(dialect Dialect, db *sql.DB, fsys fs.FS, opts ...ProviderOption
 		registered:      make(map[int64]*Migration),
 		excludePaths:    make(map[string]bool),
 		excludeVersions: make(map[int64]bool),
-		logger:          &stdLogger{},
 	}
 	for _, opt := range opts {
 		if err := opt.apply(&cfg); err != nil {
@@ -72,16 +73,25 @@ func NewProvider(dialect Dialect, db *sql.DB, fsys fs.FS, opts ...ProviderOption
 	}
 	// Allow users to specify a custom store implementation, but only if they don't specify a
 	// dialect. If they specify a dialect, we'll use the default store implementation.
-	if dialect == "" && cfg.store == nil {
-		return nil, errors.New("dialect must not be empty")
+	if dialect == DialectCustom && cfg.store == nil {
+		return nil, errors.New("custom store must be supplied when using a custom dialect, make sure to pass WithStore option")
 	}
-	if dialect != "" && cfg.store != nil {
-		return nil, errors.New("dialect must be empty when using a custom store implementation")
+	if dialect != DialectCustom && cfg.store != nil {
+		return nil, errors.New("custom store must not be specified when using one of the default dialects, use DialectCustom instead")
+	}
+	// Allow table name to be set only if store is not set.
+	if cfg.tableName != "" && cfg.store != nil {
+		return nil, errors.New("WithTableName cannot be used with WithStore; set the table name directly on your custom store")
+	}
+
+	// Set default logger if neither was provided
+	if cfg.slogger == nil && cfg.logger == nil {
+		cfg.logger = &stdLogger{}
 	}
 	var store database.Store
 	if dialect != "" {
 		var err error
-		store, err = database.NewStore(dialect, DefaultTablename)
+		store, err = database.NewStore(dialect, cmp.Or(cfg.tableName, DefaultTablename))
 		if err != nil {
 			return nil, err
 		}
@@ -156,16 +166,16 @@ func (p *Provider) Status(ctx context.Context) ([]*MigrationStatus, error) {
 // HasPending returns true if there are pending migrations to apply, otherwise, it returns false. If
 // out-of-order migrations are disabled, yet some are detected, this method returns an error.
 //
-// Note, this method will not use a SessionLocker if one is configured. This allows callers to check
-// for pending migrations without blocking or being blocked by other operations.
+// Note, this method will not use a SessionLocker or Locker if one is configured. This allows
+// callers to check for pending migrations without blocking or being blocked by other operations.
 func (p *Provider) HasPending(ctx context.Context) (bool, error) {
 	return p.hasPending(ctx)
 }
 
 // GetVersions returns the max database version and the target version to migrate to.
 //
-// Note, this method will not use a SessionLocker if one is configured. This allows callers to check
-// for versions without blocking or being blocked by other operations.
+// Note, this method will not use a SessionLocker or Locker if one is configured. This allows
+// callers to check for versions without blocking or being blocked by other operations.
 func (p *Provider) GetVersions(ctx context.Context) (current, target int64, err error) {
 	return p.getVersions(ctx)
 }
@@ -435,7 +445,11 @@ func (p *Provider) down(
 	}
 	// We never migrate the zero version down.
 	if dbMigrations[0].Version == 0 {
-		p.printf("no migrations to run, current version: 0")
+		p.logf(ctx,
+			"no migrations to run, current version: 0",
+			"no migrations to run",
+			slog.Int64("version", 0),
+		)
 		return nil, nil
 	}
 	var apply []*Migration
@@ -472,6 +486,16 @@ func (p *Provider) apply(
 		retErr = multierr.Append(retErr, cleanup())
 	}()
 
+	d := sqlparser.DirectionDown
+	if direction {
+		d = sqlparser.DirectionUp
+	}
+
+	if p.cfg.disableVersioning {
+		// If versioning is disabled, we simply run the migration.
+		return p.runMigrations(ctx, conn, []*Migration{m}, d, true)
+	}
+
 	result, err := p.store.GetMigration(ctx, conn, version)
 	if err != nil && !errors.Is(err, database.ErrVersionNotFound) {
 		return nil, err
@@ -489,10 +513,6 @@ func (p *Provider) apply(
 	if !direction && result == nil {
 		return nil, fmt.Errorf("version %d: %w", version, ErrNotApplied)
 	}
-	d := sqlparser.DirectionDown
-	if direction {
-		d = sqlparser.DirectionUp
-	}
 	return p.runMigrations(ctx, conn, []*Migration{m}, d, true)
 }
 
